# linked-claims-extractor
Extract claims from text, url or pdf using AI LLMs to help

## Installation

This project uses pyproject.toml for dependencies

```
python -m venv .venv
. .venv/bin/activate
pip install -e .
```

## Testing and Debugging

```
pytest -s --pdb
```
